@@ -11,9 +11,9 @@ if [ -z "${TCLVERS}" ]; then
 	exit 1
 fi
 
-ZLIBVERS="1.2.3"
+ZLIBVERS="1.2.4"
 SRC="src/zlib-${ZLIBVERS}.tar.gz"
-SRCURL="http://www.zlib.net/zlib-${ZLIBVERS}.tar.gz"
+SRCURL="http://sourceforge.net/projects/libpng/files/zlib/${ZLIBVERS}/zlib-${ZLIBVERS}.tar.gz/download"
 BUILDDIR="$(pwd)/build/zlib-${ZLIBVERS}"
 OUTDIR="$(pwd)/out"
 INSTDIR="$(pwd)/inst"
